Python interface
================

You can use the Python interface:

.. code-block:: python

    from reacnetgenerator import ReacNetGenerator
    ReacNetGenerator(inputfiletype="dump", inputfilename="dump.ch4", atomname=['C', 'H', 'O']).runanddraw()

Details of interface are given below.

.. automodule:: reacnetgenerator
   :members:

.. automodule:: reacnetgenerator.gui
   :members:
